@@ -188,6 +188,9 @@ class AppBuildCommand(CliCommand):
                 service['network_mode'] = 'host'
             if 'volumes' not in service:
                 service['volumes'] = [f'/data/app/{meta["app-name"]}/data:/data']
+            if 'environment' not in service:
+                service['environment'] = ['PYTHONUNBUFFERED=1']
+
             # older docker-compose get confused about the platform and build tags
             if 'platform' in service:
                 del service['platform']
