@@ -20,12 +20,16 @@ def get_version():
 class PersistentState:
     def __init__(self):
         user_home = Path.home()
-        if not user_home.exists():
-            eprint('Warning: User home directory could not be determined')
-            self._initialized = False
-            return
-        self._initialized = True
         self.persistent_dir = user_home / ".auterion-cli"
+
+        # make sure the persistent dir exits
+        # Older auterion-cli had .auterion-cli as a file. Remove that file if it exists
+        if self.persistent_dir.exists() and self.persistent_dir.is_file():
+            os.unlink(self.persistent_dir)
+
+        if not self.persistent_dir.exists():
+            os.mkdir(self.persistent_dir)
+
         self._config_path = self.persistent_dir / "persistent.json"
 
         self._config = {}
@@ -62,13 +66,6 @@ class PersistentState:
         if persist_hash == self._load_hash:
             return
 
-        # Older auterion-cli had .auterion-cli as a file. Remove that file if it exists
-        if self.persistent_dir.exists() and self.persistent_dir.is_file():
-            os.unlink(self.persistent_dir)
-
-        if not self.persistent_dir.exists():
-            os.mkdir(self.persistent_dir)
-
         with open(self._config_path, 'w') as f:
             f.write(contents)
 
